@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2008, 2009 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2008-2022 Rolf Eike Beer <kde@opensource.sf-tec.de>
 
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
@@ -26,7 +26,7 @@ protected:
 
 public:
 	explicit KGpgSubkeyNode(KGpgKeyNode *parent, const KgpgCore::KgpgKeySub &k);
-    ~KGpgSubkeyNode() override;
+	~KGpgSubkeyNode() override = default;
 
 	KgpgCore::KgpgItemType getType() const override;
 	KgpgCore::KgpgKeyTrust getTrust() const override;
