@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2016 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2007-2022 Rolf Eike Beer <kde@opensource.sf-tec.de>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef GPGPROC_H
@@ -42,7 +42,7 @@ public:
     /**
      * Destructor
      */
-    ~GPGProc() override;
+    ~GPGProc() override = default;
 
     /**
      *  Starts the process
