@@ -6,7 +6,7 @@
 
 class KGpgExportTest : public QObject {
 	Q_OBJECT
-private slots:
+private Q_SLOTS:
 	void init();
 	void testExportPublicKeyToFile();
 	void testExportSecretKeyToFile();
