@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2008, 2009 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2008-2022 Rolf Eike Beer <kde@opensource.sf-tec.de>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -21,7 +21,7 @@ class KGpgAddUid: public KGpgEditKeyTransaction {
 	Q_DISABLE_COPY(KGpgAddUid)
 public:
 	KGpgAddUid(QObject *parent, const QString &keyid, const QString &name, const QString &email = QString(), const QString &comment = QString());
-    ~KGpgAddUid() override;
+	~KGpgAddUid() override = default;
 
 	void setName(const QString &name);
 	void setEmail(const QString &email);
