@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2009 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2009-2022 Rolf Eike Beer <kde@opensource.sf-tec.de>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -37,7 +37,7 @@ public:
 	/**
 	 * @brief destructor
 	 */
-    ~KGpgSignKey() override;
+	~KGpgSignKey() override = default;
 
 protected:
 	bool nextLine(const QString &line) override;
